@@ -255,12 +255,14 @@ fn format_data<W: EventWriter>(writer: &mut W, val: &_SerializerData, state: &mu
                                     };
                                     if !state.ns_stack.iter().any(|ns| ns == n) {
                                         if let Some(l) = caps.name("l") {
-                                            loc.push_str(&format!("{} {}", n, l.as_str()));
+                                            if !l.as_str().is_empty() {
+                                                loc.push_str(&format!("{} {}", n, l.as_str()));
+                                            }
                                         } else {
                                             let last_n = n.rsplit(':').next().unwrap();
                                             loc.push_str(&format!("{} {}.xsd", n, last_n));
                                         }
-                                        if state.include_schema_location {
+                                        if state.include_schema_location && !loc.is_empty() {
                                             elm = elm.attr(xml::name::Name {
                                                 namespace: None,
                                                 local_name: "schemaLocation",
@@ -318,12 +320,14 @@ fn format_data<W: EventWriter>(writer: &mut W, val: &_SerializerData, state: &mu
                                 };
                                 if !state.ns_stack.iter().any(|ns| ns == n) {
                                     if let Some(l) = caps.name("l") {
-                                        loc.push_str(&format!("{} {}", n, l.as_str()));
+                                        if !l.as_str().is_empty() {
+                                            loc.push_str(&format!("{} {}", n, l.as_str()));
+                                        }
                                     } else {
                                         let last_n = n.rsplit(':').next().unwrap();
                                         loc.push_str(&format!("{} {}.xsd", n, last_n));
                                     }
-                                    if state.include_schema_location {
+                                    if state.include_schema_location && !loc.is_empty() {
                                         elm = elm.attr(xml::name::Name {
                                             namespace: None,
                                             local_name: "schemaLocation",
